#
# spec file for package java-9-openjdk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?aarch64:%global aarch64 aarch64 arm64 armv8}
%{!?arm6:%global arm6 armv3l armv4b armv4l armv4tl armv5b armv5l armv5teb armv5tel armv5tejl armv6l armv6hl}
%global jit_arches %{ix86} x86_64 ppc64 ppc64le %{aarch64} %{arm} s390x
%global debug 0
%global buildoutputdir build
%global oldname java-1_9_0-openjdk
# Convert an absolute path to a relative path.  Each symbolic link is
# specified relative to the directory in which it is installed so that
# it will resolve properly within chrooted installations.
%global script 'use File::Spec; print File::Spec->abs2rel($ARGV[0], $ARGV[1])'
%global abs2rel perl -e %{script}
%global syslibdir       %{_libdir}
%global archname        %{name}
# Standard JPackage naming and versioning defines.
%global majorver        9
%global minorver        0
%global securityver     4
%global patchver        0
%global buildver        12
%global root_project    jdk-updates
%global root_repository jdk9u
%global root_revision   2e265b4b8622
%global corba_revision  2ef36e70f490
%global hotspot_revision a470bcec6bb8
%global jaxp_revision   95a71f690b44
%global jaxws_revision  f4f878b5f01c
%global jdk_revision    a779673ab57d
%global langtools_revision e2bf77b3f002
%global nashorn_revision fb3f7ae74bf6
%global icedtea_sound_version 1.0.1
%global java_atk_wrapper_version 0.33.2
# priority must be 6 digits in total
%global priority        1905
%global javaver         %{majorver}
# Standard JPackage directories and symbolic links.
%global sdklnk          java-%{javaver}-openjdk
%global archname        %{sdklnk}
%global jrelnk          jre-%{javaver}-openjdk
%global jrebindir       %{_jvmdir}/%{jrelnk}/bin
%global sdkdir          %{sdklnk}-%{javaver}
%global sdkbindir       %{_jvmdir}/%{sdklnk}/bin
# Prevent brp-java-repack-jars from being run.
%global __jar_repack 0
# cacert symlink
%global cacerts  %{_jvmdir}/%{sdkdir}/lib/security/cacerts
# real file made by update-ca-certificates
%global javacacerts %{_var}/lib/ca-certificates/java-cacerts
%global bootcycle 1
# turn zero on non jit arches by default
%ifnarch %{jit_arches}
%global _with_zero 1
%endif
%if %{debug}
%global debugbuild slowdebug
%else
%global debugbuild release
%endif
%if %{bootcycle}
%global imagesdir bootcycle-build/images
%global imagestarget bootcycle-images all
%else
%global imagesdir images
%global imagestarget all
%endif
# bnc#542545
# 32-bit versus 64-bit specific provides:
%ifarch %{ix86} ppc s390
%global bits 32
%endif
%ifarch x86_64 ia64 s390x
%global bits 64
%endif
%if 0%{?__isa_bits}
%global bits %{__isa_bits}
%endif
# Turn on/off some features depending on openSUSE version
%if 0%{?suse_version} > 1320
%global with_system_pcsc 1
%else
%global with_system_pcsc 0
%endif
%global with_pulseaudio 1
%bcond_with zero
%if ! %{with zero}
%ifarch x86_64
%global _with_aot 1
%endif
%endif
%bcond_with aot
%if ! %{with zero}
%global with_systemtap 1
%else
%global with_systemtap 0
%endif
%if %{with_systemtap}
%global tapsetroot      %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
%if %{with_systemtap}
# Where to install systemtap tapset (links)
# We would like these to be in a package specific subdir,
# but currently systemtap doesn't support that, so we have to
# use the root tapset dir for now. To distinquish between 64
# and 32 bit architectures we place the tapsets under the arch
# specific dir (note that systemtap will only pickup the tapset
# for the primary arch for now). Systemtap uses the machine name
# aka build_cpu as architecture specific directory name.
%global tapsetroot %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
Name:           java-9-openjdk
Version:        %{majorver}.%{minorver}.%{securityver}.%{patchver}
Release:        bp153.1.250
Summary:        OpenJDK 9 Runtime Environment
License:        Apache-1.1 AND Apache-2.0 AND GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-with-classpath-exception AND LGPL-2.0-only AND MPL-1.0 AND MPL-1.1 AND SUSE-Public-Domain AND W3C
Group:          Development/Languages/Java
URL:            http://openjdk.java.net/
# Sources from upstream OpenJDK9 project.
Source0:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/archive/%{root_revision}.tar.bz2
Source1:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/corba/archive/%{corba_revision}.tar.bz2
Source2:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/hotspot/archive/%{hotspot_revision}.tar.bz2
Source3:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/jaxp/archive/%{jaxp_revision}.tar.bz2
Source4:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/jaxws/archive/%{jaxws_revision}.tar.bz2
Source5:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/jdk/archive/%{jdk_revision}.tar.bz2
Source6:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/langtools/archive/%{langtools_revision}.tar.bz2
Source7:        http://hg.openjdk.java.net/%{root_project}/%{root_repository}/nashorn/archive/%{nashorn_revision}.tar.bz2
# Accessibility support
Source8:        ftp://ftp.gnome.org/pub/GNOME/sources/java-atk-wrapper/0.33/java-atk-wrapper-%{java_atk_wrapper_version}.tar.xz
# Pulseaudio support
Source9:        http://icedtea.classpath.org/download/source/icedtea-sound-%{icedtea_sound_version}.tar.xz
# Systemtap tapsets. Zipped up to keep it small.
Source10:       systemtap-tapset.tar.xz
# Desktop files. Adapated from IcedTea.
Source11:       jconsole.desktop.in
Source12:       policytool.desktop.in
# nss configuration file
Source13:       nss.cfg
# Ensure we aren't using the limited crypto policy
Source14:       TestCryptoLevel.java
# Ensure ECDSA is working
Source15:       TestECDSA.java
# New versions of config files with aarch64 support. This is not upstream yet.
Source100:      config.guess
Source101:      config.sub
# RPM/distribution specific patches
Patch1:         icedtea-sound-1.0.1-jdk9.patch
Patch2:         icedtea-sound-soundproperties.patch
# Restrict access to java-atk-wrapper classes
Patch3:         java-atk-wrapper-security.patch
# RHBZ 808293
Patch4:         PStack-808293.patch
# Allow multiple initialization of PKCS11 libraries
Patch5:         multiple-pkcs11-library-init.patch
# Fix instantiation of VM on ZERO
Patch8:         zero-ranges.patch
# From icedtea: Increase default memory limits
Patch10:        memory-limits.patch
# Fix use of unintialized memory in adlc parser
Patch12:        adlc-parser.patch
# Fix: implicit-pointer-decl
Patch13:        implicit-pointer-decl.patch
Patch14:        missing-return.patch
#
Patch15:        system-pcsclite.patch
#
# OpenJDK specific patches
#
Patch100:       s390-java-opts.patch
Patch101:       s390-size_t.patch
#
Patch102:       sorted-diff.patch
Patch103:       jdk9-gcc6.patch
#
Patch200:       ppc_stack_overflow_fix.patch
Patch201:       zero-atomic_copy64.patch
Patch202:       fix_armv6_build.patch
#
Patch300:       java-9-openjdk-linuxfilestore.patch
Patch301:       bootcycle_jobs.patch
Patch302:       disable-doclint-by-default.patch
Patch303:       alternative-tzdb_dat.patch
#
Patch400:       jaw-misc.patch
Patch401:       jaw-jdk9.patch
Patch800:       java9-improved-fonts.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  binutils
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gtk2-devel
BuildRequires:  java-ca-certificates
BuildRequires:  libX11-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXt-devel
BuildRequires:  libXtst-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  xprop
BuildRequires:  zip
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
# Requires rest of java
Requires:       %{name}-headless = %{version}-%{release}
Requires:       fontconfig
# mozilla-nss has to be installed to prevent
# java.security.ProviderException: Could not initialize NSS
# ...
# java.io.FileNotFoundException: /usr/lib64/libnss3.so
#was bnc#634793
Requires:       mozilla-nss
Requires(post): file
Requires(post): java-ca-certificates
# Standard JPackage base provides.
Provides:       java = %{javaver}
Provides:       java-%{javaver} = %{version}-%{release}
Provides:       java-openjdk = %{version}-%{release}
Provides:       jre = %{javaver}
Provides:       jre-%{javaver} = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk = %{version}-%{release}
Provides:       jre-openjdk = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       java-fonts = %{version}
# Required at least by fop
Provides:       %{oldname} = %{version}-%{release}
Provides:       java-%{bits} = %{javaver}
Provides:       java-%{javaver}-%{bits}
Provides:       java-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-%{bits} = %{javaver}
Provides:       jre-%{javaver}-%{bits}
Provides:       jre-%{javaver}-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-openjdk-%{bits} = %{version}-%{release}
Provides:       jre1.3.x
Provides:       jre1.4.x
Provides:       jre1.5.x
Provides:       jre1.6.x
Provides:       jre1.7.x
Provides:       jre1.8.x
Provides:       jre1.9.x
Obsoletes:      %{oldname} < %{version}-%{release}
%if %{bootcycle}
BuildRequires:  java-devel >= 1.8
BuildConflicts: java-devel >= 10
%else
BuildRequires:  %{name}-devel
%endif
# Zero-assembler build requirement.
%if %{with zero}
BuildRequires:  libffi-devel
%endif
%if %{with_systemtap}
BuildRequires:  systemtap-sdt-devel
%endif
# pulse audio requirements
%if %{with_pulseaudio}
BuildRequires:  libpulse-devel >= 0.9.11
BuildRequires:  pulseaudio >= 0.9.11
%endif
%if %{with_system_pcsc}
BuildRequires:  pcsc-lite-devel
%endif
%if %{with aot}
BuildRequires:  libelf-devel
%endif

%description
The OpenJDK 9 runtime environment.

%package headless
Summary:        OpenJDK 9 Runtime Environment
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
Recommends:     tzdata-java8
# Standard JPackage base provides.
Provides:       java-%{javaver}-headless = %{version}-%{release}
Provides:       java-headless = %{javaver}
Provides:       java-openjdk-headless = %{version}-%{release}
Provides:       jre-%{javaver}-headless = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk-headless = %{version}-%{release}
Provides:       jre-headless = %{javaver}
Provides:       jre-openjdk-headless = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       %{oldname}-headless = %{version}-%{release}
Provides:       jaas = %{version}
Provides:       java-sasl = %{version}
Provides:       jce = %{version}
Provides:       jdbc-stdext = 4.3
Provides:       jndi = %{version}
Provides:       jndi-cos = %{version}
Provides:       jndi-dns = %{version}
Provides:       jndi-ldap = %{version}
Provides:       jndi-rmi = %{version}
Provides:       jsse = %{version}
Obsoletes:      %{oldname}-headless < %{version}-%{release}

%description headless
The OpenJDK 9 runtime environment without audio and video support.

%package devel
Summary:        OpenJDK 9 Development Environment
# Require base package.
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
# Standard JPackage devel provides.
Provides:       %{oldname}-devel = %{version}-%{release}
Provides:       java-%{javaver}-devel = %{version}
Provides:       java-devel = %{javaver}
Provides:       java-devel-openjdk = %{version}
Provides:       java-sdk = %{javaver}
Provides:       java-sdk-%{javaver} = %{version}
Provides:       java-sdk-%{javaver}-openjdk = %{version}
Provides:       java-sdk-openjdk = %{version}
Obsoletes:      %{oldname}-devel < %{version}-%{release}

%description devel
The OpenJDK 9 development tools.

%package jmods
Summary:        JMods for OpenJDK 9
Group:          Development/Languages/Java
Requires:       %{name}-devel = %{version}-%{release}

%description jmods
The JMods for OpenJDK.

%package demo
Summary:        OpenJDK 9 Demos
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Provides:       %{oldname}-demo = %{version}-%{release}
Obsoletes:      %{oldname}-demo < %{version}-%{release}

%description demo
The OpenJDK 9 demos.

%package src
Summary:        OpenJDK 9 Source Bundle
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Provides:       %{oldname}-src = %{version}-%{release}
Obsoletes:      %{oldname}-src < %{version}-%{release}

%description src
The OpenJDK 9 source bundle.

%package javadoc
Summary:        OpenJDK 9 API Documentation
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install javadoc alternative.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall javadoc alternative.
Requires(postun): update-alternatives
# Standard JPackage javadoc provides.
Provides:       %{oldname}-javadoc = %{version}-%{release}
Provides:       java-%{javaver}-javadoc = %{version}-%{release}
Provides:       java-javadoc = %{version}-%{release}
Obsoletes:      %{oldname}-javadoc < %{version}-%{release}
BuildArch:      noarch

%description javadoc
The OpenJDK 9 API documentation.

%package accessibility
Summary:        OpenJDK 9 accessibility connector
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       xprop
Provides:       %{oldname}-accessibility = %{version}-%{release}
Obsoletes:      %{oldname}-accessibility < %{version}-%{release}

%description accessibility
Enables accessibility support in OpenJDK 9 by using java-atk-wrapper. This allows
compatible at-spi2 based accessibility programs to work for AWT and Swing-based
programs.

Please note, the java-atk-wrapper is still in beta, and OpenJDK 9 itself is still
being tuned to be working with accessibility features. There are known issues
with accessibility on, so please do not install this package unless you really
need to.

%prep
%setup -q -n %{root_repository}-%{root_revision}
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 1
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 2
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 3
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 4
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 5
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 6
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 7
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 8
%setup -q -D -n %{root_repository}-%{root_revision} -T -a 9

# Set up the build tree using the subrepository tarballs
mv corba-%{corba_revision} corba
mv hotspot-%{hotspot_revision} hotspot
mv jaxp-%{jaxp_revision} jaxp
mv jaxws-%{jaxws_revision} jaxws
mv jdk-%{jdk_revision} jdk
mv langtools-%{langtools_revision} langtools
mv nashorn-%{nashorn_revision} nashorn

# replace outdated configure guess script
#
# the configure macro will do this too, but it also passes a few flags not
# supported by openjdk configure script
cp %{SOURCE100} common/autoconf/build-aux/
cp %{SOURCE101} common/autoconf/build-aux/

# Remove libraries that are linked
rm -rvf jdk/src/java.base/share/native/libzip/zlib-*
find jdk/src/java.desktop/share/native/libjavajpeg ! -name imageioJPEG.c ! -name jpegdecoder.c -type f -delete
rm -rvf jdk/src/java.desktop/share/native/libsplashscreen/libpng
rm -rvf jdk/src/java.desktop/share/native/libsplashscreen/giflib
rm -rvf jdk/src/java.desktop/share/native/liblcms/cms*
rm -rvf jdk/src/java.desktop/share/native/liblcms/lcms2*

%patch1
%if %{with_pulseaudio}
%patch2 -p1
%endif

%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch8 -p1
%patch10 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1

%if %{with_system_pcsc}
%patch15 -p1
%endif

# s390 build fixes

%ifarch s390
%patch100 -p1
%patch101 -p1
%endif

%patch102 -p1

%if 0%{?suse_version} >= 1330
%patch103 -p1
%endif

%patch200 -p1
%patch201 -p1

%ifarch %{arm6}
%patch202 -p0
%endif

%patch300 -p1
%patch301 -p1
%patch302 -p1
%patch303 -p1

%patch800 -p1

%patch400
%patch401

# Extract systemtap tapsets

%if %{with_systemtap}

tar -x -I xz -f %{SOURCE10}

for file in tapset/*.in; do

    OUTPUT_FILE=`echo $file | sed -e s:\.in$::g`
    sed -e s:@ABS_SERVER_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/server/libjvm.so:g $file > $file.1
# TODO find out which architectures other than ix86 have a client vm

%ifarch %{ix86} %{arm6}
    sed -e s:@ABS_CLIENT_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/client/libjvm.so:g $file.1 > $OUTPUT_FILE
%else
    sed -e '/@ABS_CLIENT_LIBJVM_SO@/d' $file.1 > $OUTPUT_FILE
%endif
    sed -i -e s:@ABS_JAVA_HOME_DIR@:%{_jvmdir}/%{sdkdir}:g $OUTPUT_FILE

done

%endif

# Prepare desktop files
for file in %{SOURCE11} %{SOURCE12} ; do
    OUTPUT_FILE=`basename $file | sed -e s:\.in$::g`
    sed -e s:@JAVA_HOME@:%{_jvmdir}/%{sdkdir}:g $file > $OUTPUT_FILE
    sed -i -e s:@VERSION@:%{javaver}.%{_arch}:g $OUTPUT_FILE
done

%build
# How many cpu's do we have?
export NUM_PROC=`%{_bindir}/getconf _NPROCESSORS_ONLN 2> /dev/null || :`
export NUM_PROC=${NUM_PROC:-1}

# Build OpenJDK.

%ifarch s390x sparc64 alpha ppc64 ppc64le %{aarch64}
export ARCH_DATA_MODEL=64
%endif

%ifarch alpha
export CFLAGS="$CFLAGS -mieee"
%endif

EXTRA_CFLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"
EXTRA_CPP_FLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"

%ifarch ppc64 ppc64le ppc
EXTRA_CFLAGS="$EXTRA_CFLAGS -fno-strict-aliasing"
%endif

%if 0%{?suse_version} >= 1330
EXTRA_CFLAGS="$EXTRA_CFLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse -fpermissive"
EXTRA_CPP_FLAGS="$EXTRA_CPP_FLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse"
%endif

(cd common/autoconf
 bash ./autogen.sh
)

mkdir -p %{buildoutputdir}

pushd %{buildoutputdir}

bash ../configure \
    --with-version-major=%{majorver} \
    --with-version-minor=%{minorver} \
    --with-version-security=%{securityver} \
    --with-version-patch=%{patchver} \
    --with-version-build=%{buildver} \
    --with-version-pre="" \
    --with-version-opt="suse-%{release}-%{_arch}" \
    --disable-warnings-as-errors \
%if %{with zero}
    --with-jvm-variants=zero \
%else
%ifarch %{arm6}
    --with-jvm-variants=client \
%endif
%endif
%if %{with aot}
    --enable-aot \
%else
    --disable-aot \
%endif
    --disable-zip-debug-info \
    --disable-keep-packaged-modules \
    --with-debug-level=%{debugbuild} \
    --with-zlib=system \
    --with-libjpeg=system \
    --with-giflib=system \
    --with-libpng=system \
    --with-lcms=system \
%if %{with_system_pcsc}
    --with-pcsclite=system \
%endif
    --with-stdc++lib=dynamic \
%ifnarch %{arm}
    --with-num-cores="$NUM_PROC" \
%endif
%ifarch s390
    --with-boot-jdk-jvmargs="-Xms256M -Xmx768M" \
%endif
    --with-extra-cxxflags="$EXTRA_CPP_FLAGS" \
    --with-extra-cflags="$EXTRA_CFLAGS" \
    --disable-javac-server

# The combination of FULL_DEBUG_SYMBOLS=0 and ALT_OBJCOPY=/does_not_exist
# disables FDS for all build configs and reverts to pre-FDS make %{?_smp_mflags} logic.
# STRIP_POLICY=none says don't do any stripping. DEBUG_BINARIES=true says
# ignore all the other logic about which debug options and just do '-g'.

make \
    JAVAC_FLAGS=-g \
    LOG=trace \
    DEBUG_BINARIES=true \
    STRIP_POLICY=no_strip \
    POST_STRIP_CMD="" \
    WARNINGS_ARE_ERRORS="-Wno-error" \
    CFLAGS_WARNINGS_ARE_ERRORS="-Wno-error" \
    %{imagestarget} docs

# remove redundant *diz and *debuginfo files
find %{imagesdir}/jdk -iname '*.diz' -exec rm {} \;
find %{imagesdir}/jdk -iname '*.debuginfo' -exec rm {} \;

popd >& /dev/null

export JAVA_HOME=$(pwd)/%{buildoutputdir}/%{imagesdir}/jdk

# Copy tz.properties
echo "sun.zoneinfo.dir=%{_datadir}/javazi" >> $JAVA_HOME/conf/tz.properties

%if %{with_pulseaudio}
# Build the pulseaudio plugin
pushd icedtea-sound-%{icedtea_sound_version}
autoreconf --force --install
%configure \
    --with-jdk-home=$JAVA_HOME \
    --disable-docs
make %{?_smp_mflags}
cp icedtea-sound.jar $JAVA_HOME/../jmods/
cp build/native/libicedtea-sound.so $JAVA_HOME/lib/
popd
# Merge the icedtea-sound into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "icedtea.sound,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk
%endif

# Build the accessibility plugin
pushd java-atk-wrapper-%{java_atk_wrapper_version}
autoreconf --force --install
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
%configure \
	--without-jdk-auto-detect \
	JDK_SRC=$JAVA_HOME
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
make %{?_smp_mflags}
cp wrapper/java-atk-wrapper.jar $JAVA_HOME/../jmods/
cp jni/src/.libs/libatk-wrapper.so $JAVA_HOME/lib/
popd
# Merge the java-atk-wrapper into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "atk.wrapper,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# cacerts are generated in runtime in openSUSE
if [ -f %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts ]; then
        rm %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts
fi

# Check debug symbols are present and can identify code
SERVER_JVM="$JAVA_HOME/lib/server/libjvm.so"
if [ -f "$SERVER_JVM" ] ; then
  nm -aCl "$SERVER_JVM" | grep javaCalls.cpp
fi
CLIENT_JVM="$JAVA_HOME/lib/client/libjvm.so"
if [ -f "$CLIENT_JVM" ] ; then
  nm -aCl "$CLIENT_JVM" | grep javaCalls.cpp
fi
ZERO_JVM="$JAVA_HOME/lib/zero/libjvm.so"
if [ -f "$ZERO_JVM" ] ; then
  nm -aCl "$ZERO_JVM" | grep javaCalls.cpp
fi

# Check unlimited policy has been used
$JAVA_HOME/bin/javac -d . %{SOURCE14}
$JAVA_HOME/bin/java --add-opens java.base/javax.crypto=ALL-UNNAMED TestCryptoLevel

# Check ECC is working
$JAVA_HOME/bin/javac -d . %{SOURCE15}
#FIXME make it run after system NSS support?
$JAVA_HOME/bin/java $(echo $(basename %{SOURCE15})|sed "s|\.java||") || true

%install
export LANG=en_US.UTF-8
#bnc#530046
export STRIP_KEEP_SYMTAB=libjvm*
# skip /usr/lib/rpm/brp-check-bytecode-version:
export NO_BRP_CHECK_BYTECODE_VERSION=true

%if %{with_systemtap}
  # Install systemtap support files.
  install -dm 755 %{buildroot}%{_jvmdir}/%{sdkdir}/tapset
  cp -a tapset/*.stp %{buildroot}%{_jvmdir}/%{sdkdir}/tapset/
  install -d -m 755 %{buildroot}%{tapsetdir}
  pushd %{buildroot}%{tapsetdir}
    RELATIVE=$(%{abs2rel} %{_jvmdir}/%{sdkdir}/tapset %{tapsetdir})
    ln -sf $RELATIVE/*.stp .
  popd
%endif

pushd %{buildoutputdir}/%{imagesdir}/jdk

  # Install main files.
  install -d -m 755 %{buildroot}%{_jvmdir}/%{sdkdir}
  cp -a bin include lib conf release %{buildroot}%{_jvmdir}/%{sdkdir}

  # Install JCE policy symlinks.
  install -d -m 755 %{buildroot}%{_jvmprivdir}/%{archname}/jce/vanilla

  # Install versionless symlinks.
  pushd %{buildroot}%{_jvmdir}
    ln -sf %{sdkdir} %{jrelnk}
    ln -sf %{sdkdir} %{sdklnk}
  popd

  # Remove javaws man page
  rm -f man/man1/javaws*

  # Install man pages.
  install -d -m 755 %{buildroot}%{_mandir}/man1
  for manpage in man/man1/*
  do
    # Convert man pages to UTF8 encoding.
    iconv -f ISO_8859-1 -t UTF8 $manpage -o $manpage.tmp
    mv -f $manpage.tmp $manpage
    install -m 644 -p $manpage %{buildroot}%{_mandir}/man1/$(basename \
      $manpage .1)-%{sdklnk}.1
  done

  # Install demos and samples.
  cp -a demo %{buildroot}%{_jvmdir}/%{sdkdir}
  # enable short-circuit
  mkdir -p sample/rmi
  [ -f bin/java-rmi.cgi ] && mv bin/java-rmi.cgi sample/rmi
  cp -a sample %{buildroot}%{_jvmdir}/%{sdkdir}

popd

pushd %{buildoutputdir}/%{imagesdir}

  # Install jmods
  cp -a jmods %{buildroot}%{_jvmdir}/%{sdkdir}

popd

# Install nss.cfg
install -m 644 %{SOURCE13} %{buildroot}%{_jvmdir}/%{sdkdir}/lib/security/

# Install Javadoc documentation.
install -d -m 755 %{buildroot}%{_javadocdir}
cp -a %{buildoutputdir}/images/docs %{buildroot}%{_javadocdir}/%{sdklnk}

# Install icons and menu entries.
for s in 16 24 32 48 ; do
  install -D -p -m 644 \
    jdk/src/java.desktop/unix/classes/sun/awt/X11/java-icon${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/java-%{javaver}.png
done

# Install desktop files.
install -d -m 0755 %{buildroot}%{_datadir}/{applications,pixmaps}
install -d -m 0755 %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
for d in jconsole policytool; do
    install -m 0644 $d.desktop %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
    %suse_update_desktop_file %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/$d.desktop
done

# Find demo directories.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample -type d \
  | sed 's|'%{buildroot}'|%dir |' \
  > %{name}-demo.files

# FIXME: remove SONAME entries from demo DSOs.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=436497

# Find non-documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep -v README \
  | sed 's|'%{buildroot}'||' \
  >> %{name}-demo.files
# Find documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep README \
  | sed 's|'%{buildroot}'||' \
  | sed 's|^|%doc |' \
  >> %{name}-demo.files

# Create a config file to  enable java-atk-wrapper
pushd %{buildroot}/%{_jvmdir}/%{sdkdir}/conf/
  echo "#Config file to  enable java-atk-wrapper" > accessibility.properties
  echo "" >> accessibility.properties
  echo "assistive_technologies=org.GNOME.Accessibility.AtkWrapper" >> accessibility.properties
  echo "" >> accessibility.properties
popd

# fdupes links the files from JDK to JRE, so it breaks a JRE
# use it carefully :))
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/demo
%fdupes -s %{buildroot}%{_javadocdir}/%{sdklnk}

%pre headless
# This one is not a directory anymore, but a file,
# so we need to remove the directory in order to avoid
# cpio unpacking error
if [ -d "%{_jvmdir}/%{sdkdir}/lib/modules" -a ! -L "%{_jvmdir}/%{sdkdir}/lib/modules" ]; then
  rm -rf "%{_jvmdir}/%{sdkdir}/lib/modules"
fi

%post headless
ext=.gz
# At a certain point, idlj and idlj was slave of java instead of
# javac. This allows the upgrade pass without errors.
if update-alternatives --query java | grep idlj >/dev/null 2>&1
then
  update-alternatives --remove java %{jrebindir}/java
fi
update-alternatives \
  --install %{_bindir}/java java %{jrebindir}/java %{priority} \
  --slave %{_jvmdir}/jre jre %{_jvmdir}/%{jrelnk} \
  --slave %{_bindir}/jjs jjs %{jrebindir}/jjs \
  --slave %{_bindir}/keytool keytool %{jrebindir}/keytool \
  --slave %{_bindir}/orbd orbd %{jrebindir}/orbd \
  --slave %{_bindir}/policytool policytool %{jrebindir}/policytool \
  --slave %{_bindir}/rmid rmid %{jrebindir}/rmid \
  --slave %{_bindir}/rmiregistry rmiregistry %{jrebindir}/rmiregistry \
  --slave %{_bindir}/servertool servertool %{jrebindir}/servertool \
  --slave %{_bindir}/tnameserv tnameserv %{jrebindir}/tnameserv \
  --slave %{_mandir}/man1/java.1$ext java.1$ext \
  %{_mandir}/man1/java-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jjs.1$ext jjs.1$ext \
  %{_mandir}/man1/jjs-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/keytool.1$ext keytool.1$ext \
  %{_mandir}/man1/keytool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/orbd.1$ext orbd.1$ext \
  %{_mandir}/man1/orbd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/policytool.1$ext policytool.1$ext \
  %{_mandir}/man1/policytool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmid.1$ext rmid.1$ext \
  %{_mandir}/man1/rmid-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmiregistry.1$ext rmiregistry.1$ext \
  %{_mandir}/man1/rmiregistry-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/servertool.1$ext servertool.1$ext \
  %{_mandir}/man1/servertool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/tnameserv.1$ext tnameserv.1$ext \
  %{_mandir}/man1/tnameserv-%{sdklnk}.1$ext  \
  --slave %{_datadir}/applications/policytool.desktop policytool.desktop \
  %{_jvmdir}/%{sdkdir}/lib/desktop/policytool.desktop

update-alternatives \
  --install %{_jvmdir}/jre-openjdk \
  jre_openjdk %{_jvmdir}/%{jrelnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/jre-%{javaver} \
  jre_%{javaver} %{_jvmdir}/%{jrelnk} %{priority}

%postun headless
if [ $1 -eq 0 ]
then
  if test -f /proc/sys/fs/binfmt_misc/jarexec
  then
    echo '-1' > /proc/sys/fs/binfmt_misc/jarexec
  fi
  update-alternatives --remove java %{jrebindir}/java
  update-alternatives --remove jre_openjdk %{_jvmdir}/%{jrelnk}
  update-alternatives --remove jre_%{javaver} %{_jvmdir}/%{jrelnk}
fi

%posttrans headless
# bnc#781690#c11: don't trust user defined JAVA_HOME and use the current VM
# XXX: this might conflict between various versions of openjdk
export JAVA_HOME=%{_jvmdir}/%{jrelnk}

# check if the java-cacerts is a valid keystore (bnc#781690)
if [ X"`%{_bindir}/file --mime-type -b %{javacacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
%if 0%{?suse_version} <= 1310
    # workaround for bnc#847952 - pre 13.1 keyring.jar attempts to load invalid keystore and fail on it
    rm -f "%{javacacerts}"
%endif
    %{_sbindir}/update-ca-certificates
fi

# remove the default empty cacert file, if it's installed
if [ 0`stat -c "%{s}" %{cacerts} 2>/dev/null` = "032" ] ; then
    rm -f %{cacerts}
fi

# if cacerts does exists, neither does not contain/point to a
# valid keystore (bnc#781690) ...
if [ X"`%{_bindir}/file --mime-type -b -L %{cacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
    # bnc#727223
    rm -f %{cacerts}
    ln -s %{javacacerts} %{cacerts}
fi

%post devel
ext=.gz
update-alternatives \
  --install %{_bindir}/javac javac %{sdkbindir}/javac %{priority} \
  --slave %{_jvmdir}/java java_sdk %{_jvmdir}/%{sdklnk} \
  --slave %{_bindir}/appletviewer appletviewer %{sdkbindir}/appletviewer \
  --slave %{_bindir}/idlj idlj %{jrebindir}/idlj \
%if %{with aot}
  --slave %{_bindir}/jaotc jaotc %{sdkbindir}/jaotc \
%endif
  --slave %{_bindir}/jar jar %{sdkbindir}/jar \
  --slave %{_bindir}/jarsigner jarsigner %{sdkbindir}/jarsigner \
  --slave %{_bindir}/javadoc javadoc %{sdkbindir}/javadoc \
  --slave %{_bindir}/javah javah %{sdkbindir}/javah \
  --slave %{_bindir}/javap javap %{sdkbindir}/javap \
  --slave %{_bindir}/jcmd jcmd %{sdkbindir}/jcmd \
  --slave %{_bindir}/jconsole jconsole %{sdkbindir}/jconsole \
  --slave %{_bindir}/jdb jdb %{sdkbindir}/jdb \
  --slave %{_bindir}/jdeprscan jdeprscan %{sdkbindir}/jdeprscan \
  --slave %{_bindir}/jdeps jdeps %{sdkbindir}/jdeps \
%if ! %{with zero}
  --slave %{_bindir}/jhsdb jhsdb %{sdkbindir}/jhsdb \
%endif
  --slave %{_bindir}/jimage jimage %{sdkbindir}/jimage \
  --slave %{_bindir}/jinfo jinfo %{sdkbindir}/jinfo \
  --slave %{_bindir}/jlink jlink %{sdkbindir}/jlink \
  --slave %{_bindir}/jmap jmap %{sdkbindir}/jmap \
  --slave %{_bindir}/jmod jmod %{sdkbindir}/jmod \
  --slave %{_bindir}/jps jps %{sdkbindir}/jps \
  --slave %{_bindir}/jrunscript jrunscript %{sdkbindir}/jrunscript \
  --slave %{_bindir}/jshell jshell %{sdkbindir}/jshell \
  --slave %{_bindir}/jstack jstack %{sdkbindir}/jstack \
  --slave %{_bindir}/jstat jstat %{sdkbindir}/jstat \
  --slave %{_bindir}/jstatd jstatd %{sdkbindir}/jstatd \
  --slave %{_bindir}/pack200 pack200 %{sdkbindir}/pack200 \
  --slave %{_bindir}/rmic rmic %{sdkbindir}/rmic \
  --slave %{_bindir}/schemagen schemagen %{sdkbindir}/schemagen \
  --slave %{_bindir}/serialver serialver %{sdkbindir}/serialver \
  --slave %{_bindir}/unpack200 unpack200 %{sdkbindir}/unpack200 \
  --slave %{_bindir}/wsgen wsgen %{sdkbindir}/wsgen \
  --slave %{_bindir}/wsimport wsimport %{sdkbindir}/wsimport \
  --slave %{_bindir}/xjc xjc %{sdkbindir}/xjc \
  --slave %{_mandir}/man1/appletviewer.1$ext appletviewer.1$ext \
  %{_mandir}/man1/appletviewer-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/idlj.1$ext idlj.1$ext \
  %{_mandir}/man1/idlj-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jar.1$ext jar.1$ext \
  %{_mandir}/man1/jar-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jarsigner.1$ext jarsigner.1$ext \
  %{_mandir}/man1/jarsigner-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javac.1$ext javac.1$ext \
  %{_mandir}/man1/javac-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javadoc.1$ext javadoc.1$ext \
  %{_mandir}/man1/javadoc-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javah.1$ext javah.1$ext \
  %{_mandir}/man1/javah-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javap.1$ext javap.1$ext \
  %{_mandir}/man1/javap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jcmd.1$ext jcmd.1$ext \
  %{_mandir}/man1/jcmd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jconsole.1$ext jconsole.1$ext \
  %{_mandir}/man1/jconsole-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdb.1$ext jdb.1$ext \
  %{_mandir}/man1/jdb-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdeps.1$ext jdeps.1$ext \
  %{_mandir}/man1/jdeps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jinfo.1$ext jinfo.1$ext \
  %{_mandir}/man1/jinfo-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jmap.1$ext jmap.1$ext \
  %{_mandir}/man1/jmap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jps.1$ext jps.1$ext \
  %{_mandir}/man1/jps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jrunscript.1$ext jrunscript.1$ext \
  %{_mandir}/man1/jrunscript-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstack.1$ext jstack.1$ext \
  %{_mandir}/man1/jstack-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstat.1$ext jstat.1$ext \
  %{_mandir}/man1/jstat-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstatd.1$ext jstatd.1$ext \
  %{_mandir}/man1/jstatd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/pack200.1$ext pack200.1$ext \
  %{_mandir}/man1/pack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmic.1$ext rmic.1$ext \
  %{_mandir}/man1/rmic-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/schemagen.1$ext schemagen.1$ext \
  %{_mandir}/man1/schemagen-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/serialver.1$ext serialver.1$ext \
  %{_mandir}/man1/serialver-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/unpack200.1$ext unpack200.1$ext \
  %{_mandir}/man1/unpack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/wsgen.1$ext wsgen.1$ext \
  %{_mandir}/man1/wsgen-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/wsimport.1$ext wsimport.1$ext \
  %{_mandir}/man1/wsimport-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/xjc.1$ext xjc.1$ext \
  %{_mandir}/man1/xjc-%{sdklnk}.1$ext \
  --slave %{_datadir}/applications/jconsole.desktop jconsole.desktop \
  %{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

update-alternatives \
  --install %{_jvmdir}/java-openjdk \
  java_sdk_openjdk %{_jvmdir}/%{sdklnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/java-%{javaver} \
  java_sdk_%{javaver} %{_jvmdir}/%{sdklnk} %{priority}

%postun devel
if [ $1 -eq 0 ]
then
  update-alternatives --remove javac %{sdkbindir}/javac
  update-alternatives --remove java_sdk_openjdk %{_jvmdir}/%{sdklnk}
  update-alternatives --remove java_sdk_%{javaver} %{_jvmdir}/%{sdklnk}
fi

%post javadoc
update-alternatives \
  --install %{_javadocdir}/java javadocdir %{_javadocdir}/%{sdklnk}/api \
  %{priority}

%postun javadoc
if [ $1 -eq 0 ]
then
  update-alternatives --remove javadocdir %{_javadocdir}/%{sdklnk}/api
fi

%files
%dir %{_jvmdir}/%{sdkdir}/lib
%{_jvmdir}/%{sdkdir}/lib/libawt_xawt.so
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/lib/libicedtea-sound.so
%endif
%{_jvmdir}/%{sdkdir}/lib/libjawt.so
%{_jvmdir}/%{sdkdir}/lib/libjsoundalsa.so
%{_jvmdir}/%{sdkdir}/lib/libsplashscreen.so
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/*x*/apps/java-%{javaver}.png

%files headless
%dir %{_jvmdir}
%dir %{_jvmdir}/%{sdkdir}/
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/lib
%dir %{_jvmdir}/%{sdkdir}/lib/jli
%ifarch %{arm6}
%dir %{_jvmdir}/%{sdkdir}/lib/client
%else
%dir %{_jvmdir}/%{sdkdir}/lib/server
%endif
%dir %{_jvmdir}/%{sdkdir}/lib/desktop
%dir %{_jvmdir}/%{sdkdir}/lib/security

%dir %{_jvmdir}/%{sdkdir}/conf
%dir %{_jvmdir}/%{sdkdir}/conf/security
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/limited
%dir %{_jvmdir}/%{sdkdir}/conf/management

%{_jvmdir}/%{jrelnk}
%{_jvmprivdir}/*

%{_jvmdir}/%{sdkdir}/bin/java
%{_jvmdir}/%{sdkdir}/bin/jjs
%{_jvmdir}/%{sdkdir}/bin/keytool
%{_jvmdir}/%{sdkdir}/bin/orbd
%{_jvmdir}/%{sdkdir}/bin/policytool
%{_jvmdir}/%{sdkdir}/bin/rmid
%{_jvmdir}/%{sdkdir}/bin/rmiregistry
%{_jvmdir}/%{sdkdir}/bin/servertool
%{_jvmdir}/%{sdkdir}/bin/tnameserv
%{_jvmdir}/%{sdkdir}/conf/logging.properties
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.access
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.password.template
%{_jvmdir}/%{sdkdir}/conf/management/management.properties
%{_jvmdir}/%{sdkdir}/conf/net.properties
%{_jvmdir}/%{sdkdir}/conf/security/java.policy
%{_jvmdir}/%{sdkdir}/conf/security/java.security
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/exempt_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/README.txt
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/sound.properties
%{_jvmdir}/%{sdkdir}/conf/tz.properties
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/classlist
%endif
%{_jvmdir}/%{sdkdir}/lib/desktop/policytool.desktop
%{_jvmdir}/%{sdkdir}/lib/jexec
%{_jvmdir}/%{sdkdir}/lib/jli/libjli.so
%{_jvmdir}/%{sdkdir}/lib/jrt-fs.jar
%{_jvmdir}/%{sdkdir}/lib/jvm.cfg
%{_jvmdir}/%{sdkdir}/lib/libawt_headless.so
%{_jvmdir}/%{sdkdir}/lib/libawt.so
%{_jvmdir}/%{sdkdir}/lib/libdt_socket.so
%{_jvmdir}/%{sdkdir}/lib/libfontmanager.so
%{_jvmdir}/%{sdkdir}/lib/libinstrument.so
%{_jvmdir}/%{sdkdir}/lib/libj2gss.so
%{_jvmdir}/%{sdkdir}/lib/libj2pcsc.so
%{_jvmdir}/%{sdkdir}/lib/libj2pkcs11.so
%{_jvmdir}/%{sdkdir}/lib/libjaas_unix.so
%{_jvmdir}/%{sdkdir}/lib/libjavajpeg.so
%{_jvmdir}/%{sdkdir}/lib/libjava.so
%{_jvmdir}/%{sdkdir}/lib/libjdwp.so
%{_jvmdir}/%{sdkdir}/lib/libjimage.so
%{_jvmdir}/%{sdkdir}/lib/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/libjsound.so
%{_jvmdir}/%{sdkdir}/lib/liblcms.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_agent.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_ext.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement.so
%{_jvmdir}/%{sdkdir}/lib/libmlib_image.so
%{_jvmdir}/%{sdkdir}/lib/libnet.so
%{_jvmdir}/%{sdkdir}/lib/libnio.so
%{_jvmdir}/%{sdkdir}/lib/libprefs.so
%{_jvmdir}/%{sdkdir}/lib/librmi.so
%{_jvmdir}/%{sdkdir}/lib/libsctp.so
%{_jvmdir}/%{sdkdir}/lib/libsunec.so
%{_jvmdir}/%{sdkdir}/lib/libunpack.so
%{_jvmdir}/%{sdkdir}/lib/libverify.so
%{_jvmdir}/%{sdkdir}/lib/libzip.so
%{_jvmdir}/%{sdkdir}/lib/modules
%{_jvmdir}/%{sdkdir}/lib/psfontj2d.properties
%{_jvmdir}/%{sdkdir}/lib/psfont.properties.ja
%{_jvmdir}/%{sdkdir}/lib/tzdb.dat
%{_jvmdir}/%{sdkdir}/lib/*/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/*/libjvm.so
%{_jvmdir}/%{sdkdir}/lib/*/Xusage.txt

%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/blacklisted.certs
%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/nss.cfg
%{_jvmdir}/%{sdkdir}/lib/security/default.policy

%{_mandir}/man1/java-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jjs-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/keytool-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/orbd-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/policytool-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmid-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmiregistry-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/servertool-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/tnameserv-%{sdklnk}.1%{?ext_man}

%files devel
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/include
%dir %{_jvmdir}/%{sdkdir}/include/linux
%dir %{_jvmdir}/%{sdkdir}/lib

%if %{with_systemtap}
%dir %{_jvmdir}/%{sdkdir}/tapset
%endif
%{_jvmdir}/%{sdkdir}/bin/appletviewer
%{_jvmdir}/%{sdkdir}/bin/idlj
%if %{with aot}
%{_jvmdir}/%{sdkdir}/bin/jaotc
%endif
%{_jvmdir}/%{sdkdir}/bin/jar
%{_jvmdir}/%{sdkdir}/bin/jarsigner
%{_jvmdir}/%{sdkdir}/bin/javac
%{_jvmdir}/%{sdkdir}/bin/javadoc
%{_jvmdir}/%{sdkdir}/bin/javah
%{_jvmdir}/%{sdkdir}/bin/javap
%{_jvmdir}/%{sdkdir}/bin/jcmd
%{_jvmdir}/%{sdkdir}/bin/jconsole
%{_jvmdir}/%{sdkdir}/bin/jdb
%{_jvmdir}/%{sdkdir}/bin/jdeprscan
%{_jvmdir}/%{sdkdir}/bin/jdeps
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/bin/jhsdb
%endif
%{_jvmdir}/%{sdkdir}/bin/jimage
%{_jvmdir}/%{sdkdir}/bin/jinfo
%{_jvmdir}/%{sdkdir}/bin/jlink
%{_jvmdir}/%{sdkdir}/bin/jmap
%{_jvmdir}/%{sdkdir}/bin/jmod
%{_jvmdir}/%{sdkdir}/bin/jps
%{_jvmdir}/%{sdkdir}/bin/jrunscript
%{_jvmdir}/%{sdkdir}/bin/jshell
%{_jvmdir}/%{sdkdir}/bin/jstack
%{_jvmdir}/%{sdkdir}/bin/jstat
%{_jvmdir}/%{sdkdir}/bin/jstatd
%{_jvmdir}/%{sdkdir}/bin/pack200
%{_jvmdir}/%{sdkdir}/bin/rmic
%{_jvmdir}/%{sdkdir}/bin/schemagen
%{_jvmdir}/%{sdkdir}/bin/serialver
%{_jvmdir}/%{sdkdir}/bin/unpack200
%{_jvmdir}/%{sdkdir}/bin/wsgen
%{_jvmdir}/%{sdkdir}/bin/wsimport
%{_jvmdir}/%{sdkdir}/bin/xjc
%{_jvmdir}/%{sdkdir}/include/classfile_constants.h
%{_jvmdir}/%{sdkdir}/include/ir.idl
%{_jvmdir}/%{sdkdir}/include/jawt.h
%{_jvmdir}/%{sdkdir}/include/jdwpTransport.h
%{_jvmdir}/%{sdkdir}/include/jni.h
%{_jvmdir}/%{sdkdir}/include/jvmticmlr.h
%{_jvmdir}/%{sdkdir}/include/jvmti.h
%{_jvmdir}/%{sdkdir}/include/linux/jawt_md.h
%{_jvmdir}/%{sdkdir}/include/linux/jni_md.h
%{_jvmdir}/%{sdkdir}/include/orb.idl
%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop
%{_jvmdir}/%{sdkdir}/lib/ct.sym
%{_jvmdir}/%{sdkdir}/lib/libattach.so
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/libsaproc.so
%endif
%if %{with aot}
%{_jvmdir}/%{sdkdir}/lib/libjelfshim.so
%endif

%if %{with_systemtap}
%{_jvmdir}/%{sdkdir}/tapset/*.stp
%endif
%{_jvmdir}/%{sdklnk}
%{_mandir}/man1/appletviewer-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/idlj-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jar-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jarsigner-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javac-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javadoc-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javah-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javap-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jcmd-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jconsole-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jdb-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jdeps-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jinfo-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jmap-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jps-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jrunscript-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstack-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstat-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstatd-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/pack200-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmic-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/schemagen-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/serialver-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/unpack200-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/wsgen-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/wsimport-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/xjc-%{sdklnk}.1%{?ext_man}

%if %{with_systemtap}
%{tapsetroot}
%endif

%files jmods
%dir %{_jvmdir}/%{sdkdir}/jmods
%{_jvmdir}/%{sdkdir}/release
%{_jvmdir}/%{sdkdir}/jmods/*.jmod
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/jmods/icedtea-sound.jar
%endif
%{_jvmdir}/%{sdkdir}/jmods/java-atk-wrapper.jar

%files demo -f %{name}-demo.files

%files src
%{_jvmdir}/%{sdkdir}/lib/src.zip

%files javadoc
%dir %{_javadocdir}
%dir %{_javadocdir}/%{sdklnk}
%{_javadocdir}/%{sdklnk}/*

%files accessibility
%config(noreplace) %{_jvmdir}/%{sdkdir}/conf/accessibility.properties
%{_jvmdir}/%{sdkdir}/lib/libatk-wrapper.so

%changelog
* Fri Jul  6 2018 fstrba@suse.com
- Remove the alternative for java before reinstalling it, if idlj
  is its slave (bsc#1096420)
* Wed Jun 27 2018 fstrba@suse.com
- Move idlj to *-devel package (bsc#1096420)
* Fri Jun 22 2018 fstrba@suse.com
- Added patch:
  * missing-return.patch
    + fix no-return-in-nonvoid-function
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Fix armv6 build with fix_armv6_build.patch
* Fri Mar  2 2018 fstrba@suse.com
- Modified patch:
  * system-pcsclite.patch
    + Fix merge error in the patch
* Mon Feb 19 2018 fstrba@suse.com
- Update to upstream tag jdk-9.0.4+12
  * Fixes:
    + S8194739: Zero port of 8174962: Better interface invocations
    + S8195685: AArch64: AArch64 cannot build with JDK-8174962
    + S8195859: AArch64: vtableStubs gtest fails after 8174962
    + S8196136: AArch64: Correct register use in patch for
    JDK-8195685
- Removed patches:
  * JDK-8194739-zero.patch
  * JDK-8195685-aarch64.patch
    + Integrated upstream
* Thu Jan 25 2018 fstrba@suse.com
- Modified patch:
  * JDK-8195685-aarch64.patch
    + Incorporate S8196136: AArch64: Correct register use in patch
    for JDK-8195685
* Mon Jan 22 2018 fstrba@suse.com
- Removed patch:
  * revert-8174962-for-zero.patch
    + a proper fix for ZERO exists
- Added patch:
  * JDK-8194739-zero.patch
    + S8194739: Zero port of 8174962: Better interface invocations
* Sat Jan 20 2018 fstrba@suse.com
- Removed patch:
  * revert-8174962-for-aarch64.patch
    + a proper fix for aarch64 exists
- Added patches:
  * JDK-8195685-aarch64.patch
    + S8195685, AArch64 cannot build with JDK-8174962
  * revert-8174962-for-zero.patch
    + revert "S8174962, CVE-2018-2582: Better interface invocations"
    for ZERO. The patch misses ZERO parts and causes crash
  during build.
* Thu Jan 18 2018 fstrba@suse.com
- Added patch:
  * revert-8174962-for-aarch64.patch
    + revert "S8174962, CVE-2018-2582: Better interface
    invocations" for aarch64 and zero. The patch misses aarch64
    and zero parts and causes crashes during the build on those
    architectures.
* Wed Jan 17 2018 fstrba@suse.com
- OpenJDK 9.0.4 (January 2018 CPU) - bsc#1076366
  * Security fixes:
    + S8172525, CVE-2018-2579: Improve key keying case
    + S8174962, CVE-2018-2582: Better interface invocations
    + S8178449, CVE-2018-2588: Improve LDAP logins
    + S8182125, CVE-2018-2599: Improve reliability of DNS lookups
    + S8182387, CVE-2018-2603: Improve PKCS usage
    + S8182601, CVE-2018-2602: Improve usage messages
    + S8185292, CVE-2018-2618: Stricter key generation
    + S8185325, CVE-2018-2641: Improve GTK initialization
    + S8186212, CVE-2018-2629: Improve GSS handling
    + S8186600, CVE-2018-2634: Improve property negotiations
    + S8186606, CVE-2018-2633: Improve LDAP lookup robustness
    + S8186998, CVE-2018-2637: Improve JMX supportive features
    + S8189284, CVE-2018-2663: More refactoring for deserialization
    cases
    + S8190289, CVE-2018-2677: More refactoring for client
    deserialization cases
    + S8191142, CVE-2018-2678: More refactoring for naming
    deserialization cases
  * Security-In-Depth fixes:
    + S8160104: CORBA communication improvements
    + S8174756: Extra validation for public keys
    + S8175932: Improve host instance supports
    + S8176450: Revise default document styling
    + S8178458: Better use of certificates in LDAP
    + S8178466: Better RSA parameters
    + S8179533: Cleaner print job handling
    + S8179990: Cleaner palette entry handling
    + S8180011: Cleaner native graphics device handling
    + S8180015: Cleaner AWT robot handling
    + S8180020: Improve SymbolHashMap entry handling
    + S8180869: Cleaner image file reading handling
    + S8180877: More deeply colored ICC spaces
    + S8181664: Improve JVM UTF String handling
    + S8181670: Improve implementation of keystores
    + S8186080: Transform XML interfaces
    + S8186867: Improve native glyph layouts
  * Fixes:
    + S8139653: Freetype bundled on macosx, but not correctly
    linked
    + S8140436: Negotiated Finite Field Diffie-Hellman Ephemeral
    Parameters for TLS
    + S8148421: Transport Layer Security (TLS) Session Hash and
    Extended Master Secret Extension
    + S8159377: JMX Connections need white-list filters
    + S8163237: Restrict the use of EXPORT cipher suites
    + S8163958: Improved garbage collection
    + S8165543: Better window framing
    + S8169026: Handle smartcard clean up better
    + S8169080: Improve documentation examples for crypto
    applications
    + S8169209: Improved image post-processing steps
    + S8169392: Additional jar validation steps
    + S8169966: Larger AWT menus
    + S8170218: Improved Font Metrics
    + S8170966: Right parenthesis issue
    + S8171252: Improve exception checking
    + S8171261: Stability fixes for lcms
    + S8171539: Better script accessibility for JavaScript
    + S8172204: Better Thread Pool execution
    + S8172461: Service Registration Lifecycle
    + S8172465: Better handling of channel groups
    + S8172469: Transform Transformer Exceptions
    + S8173697: Less Active Activations
    + S8173770: Image conversion improvements
    + S8174098: Better image fetching
    + S8174105: Better naming attribution
    + S8174109: Better queuing priorities
    + S8174113: Better sourcing of code
    + S8174770: Check registry registration location
    + S8174873: Improved certificate procesing
    + S8174966: Unreferenced references
    + S8175106: Higher quality DSA operations
    + S8175110: Higher quality ECDSA operations
    + S8175940: More certificate subject checking
    + S8176055: JMX diagnostic improvements
    + S8176067: Proper directory lookup processing
    + S8176731: JCK tests in api/javax_xml/transform/ spec
    conformance started failing after 8172469
    + S8176751: Better URL connections
    + S8176760: Better handling of PKCS8 material
    + S8177549: Typo in Vector.java
    + S8178135: Additional elliptic curve support
    + S8178714: PKIX validator nameConstraints check failing after
    change 8175940
    + S8178728: Check the AlgorithmParameters in algorithm
    constraints
    + S8178794: krb5 client should ignore sname in incoming tickets
    + S8179101: Improve algorithm constraints implementation
    + S8179564: Missing @bug for tests added with JDK-8165367
    + S8179998: Clear certificate chain connections
    + S8180024: Improve construction of objects during
    deserialization
    + S8180711: Better invokespecial checks
    + S8181048: Refactor existing providers to refer to the same
    constants for default values for key length
    + S8181100: Better Base Exceptions
    + S8181191: getUint32 returning Long
    + S8181323: Better timezone processing
    + S8181327: Better X processing
    + S8181370: Better keystore handling
    + S8181420: PPC: Image conversion improvements
    + S8181432: Better processing of unresolved permissions
    + S8181439: Test the jdk.tls.namedGroups System Property
    + S8181597: Process Proxy presentation
    + S8181612: More stable connection processing
    + S8181692: Update storage implementations
    + S8181788: Unable to build JDK10 on SPARC-M8 machines
    + S8182054: Improve wsdl support
    + S8182879: Add warnings to keytool when using JKS and JCEKS
    + S8183028: Improve CMS header processing
    + S8183297: Allow duplicate bugid for changeset in jdk9 update
    forest
    + S8183934: Change version number in 9.0.3 to 9.0.3
    + S8184937: LCMS error 13: Couldn't link the profiles
    + S8185928: Generate OpenJDK builds for Mac platform JDK 9.0.3
    and beyond in Mach 5
    + S8186093: A comment in the java.security configuration file
    incorrectly says that strong but "limited" is the default
    value
    + S8187482: Backout JDK-8159377
    + S8187556: Backout of a fix reintroduced a dependency that had
    since been removed
    + S8187558: Undo JDK-8159377 spec change
    + S8188194: Change version number in 9.0.4 to 9.0.4
    + S8188741: Update milestone to ea for 9.0.4+1
    + S8188789: Update JDK 9.0.1 and Future OpenJDK bundle names
    + S8188880: A JAXB JCK test failure found after 8186080
    + S8189131: Open-source the Oracle JDK Root Certificates
    + S8190258: (tz) Support tzdata2017c
    + S8190259: test tck.java.time.zone.TCKZoneRules is broken by
    tzdata2017c
    + S8190285: s390: Some java boolean checks are not correct
    + S8190464: OpenJDK on macosx needs to bundle freetype
    + S8190543: 9.0.4 L10n resource file update
    + S8190550: Update milestone to fcs for 9.0.4+5
    + S8190718: Change OpenJDK RI builds of Windows to x64
    + S8190725: Freetype license file provided with configure not
    included in images
    + S8190789: sun/security/provider/certpath/LDAPCertStore/
    /TestURICertStoreParameters.java fails after JDK-8186606
    + S8191137: keytool fails to format resource strings for keys
    for some languages after JDK-8171319
    + S8191907: PPC64 and s390 parts of JDK-8174962: Better
    interface invocations
    + S8191940: OpenJDK bundle contains closed repository
    information in release file
    + S8192773: Remove and retag 9.0.4+8 to include 8192772
    + S8192796: 9.0.4 L10n resource file update md20
    + S8192876: MacOS build fails intermittently after JDK-8139653
    + S8193208: Add missing file
    + S8193683: Increase the number of clones in the CloneableDigest
    + S8193758: Update copyright headers of files in src tree that
    are missing Classpath exception
* Thu Dec  7 2017 fstrba@suse.com
- The macro bits was not defined for aarch64 and some other
  architectures (bsc#1071624)
* Fri Dec  1 2017 fstrba@suse.com
- Run TestCryptoLevel and TestECDSA as a part of build to assure
  that the crypto works as expected
* Fri Dec  1 2017 w01dnick@gmail.com
- Added patch:
  * java9-improved-fonts.patch
    + Imports IMPROVED_FONT_RENDERING from OpenJDK 1.8.0 to use
    system fontconfig settings instead of hardcoded flags
    + Adds fontconfig dependency
- Enabled IMPROVED_FONT_RENDERING
* Thu Nov  9 2017 fstrba@suse.com
- Modified patch:
  * jaw-misc.patch
    + Do not look for gdk-3.0, since we are building against gtk2
- Added patch:
  * icedtea-sound-soundproperties.patch
    + Even though we build the pulseaudio plugin, disable it by
    default in the configuration file, since the internal openjdk
    provider is reputed to be better
* Mon Nov  6 2017 fstrba@suse.com
- Removed patch:
  * load_java_atk_wrapper.patch
    + Give up this approach that requires patching of class loaders
- Build java-atk-wrapper as a modular jar inside the OpenJDK build
- Added patches:
  * jaw-misc.patch
    + Fix some build issues and add the manifest.txt that is not
    not distributed by mistake
  * jaw-jdk9.patch
    + Make java-atk-wrapper a java module that implements the
    javax.accessibility.AccessibilityProvider interface
* Fri Nov  3 2017 fstrba@suse.com
- Packaging improvements:
  * add all binaries in JAVA_HOME/bin to alternatives in order to
    have them in the system binary path when this alternative is
    chosen
* Thu Nov  2 2017 fstrba@suse.com
- Add back the icedtea-sound plugin and integrate it into the
  system modules
- Added patch:
  * icedtea-sound-1.0.1-jdk9.patch
    + make icedtea-sound.jar modular for jdk9
- Clean some conditionals for very old %%%%suse_version
* Thu Nov  2 2017 fstrba@suse.com
- Modified patch
  * alternative-tzdb_dat.patch
    + Place the tz.properties file to JAVA_HOME/conf where OpenJDK9
    expects to have the configuration files
    + Patch also the other place in jdk that loads the tzdb.dat
    file
* Tue Oct 31 2017 fstrba@suse.com
- Remove the icedtea-sound plugin
  * it is not built or buildable, and does not work
- Removed patches:
  * icedtea-sound-1.0.1-runtime.patch
  * icedtea-sound-source_target.patch
* Fri Oct 27 2017 fstrba@suse.com
- OpenJDK 9.0.1 (October 2017 CPU)
  * Security fixes
    + S8165543: Better window framing
    + S8169026, CVE-2017-10274: Handle smartcard clean up better
    (bsc#1064071)
    + S8169966: Larger AWT menus
    + S8170218: Improved Font Metrics
    + S8171252: Improve exception checking
    + S8171261: Stability fixes for lcms
    + S8174109, CVE-2017-10281: Better queuing priorities
    (bsc#1064072)
    + S8174966, CVE-2017-10285: Unreferenced references
    (bsc#1064073)
    + S8175940: More certificate subject checking
    + S8176751, CVE-2017-10295: Better URL connections
    (bsc#1064075)
    + S8178794, CVE-2017-10388: Correct Kerberos ticket grants
    (bsc#1064086)
    + S8180024: Improve construction of objects during
    deserialization
    + S8180711, CVE-2017-10346: Better invokespecial checks
    (bsc#1064078)
    + S8181100, CVE-2017-10350: Better Base Exceptions
    (bsc#1064082)
    + S8181323, CVE-2017-10347: Better timezone processing
    (bsc#1064079)
    + S8181327, CVE-2017-10349: Better X processing (bsc#1064081)
    + S8181370, CVE-2017-10345: Better keystore handling
    (bsc#1064077)
    + S8181432, CVE-2017-10348: Better processing of unresolved
    permissions (bsc#1064080)
    + S8181597, CVE-2017-10357: Process Proxy presentation
    (bsc#1064085)
    + S8181612, CVE-2017-10355: More stable connection processing
    (bsc#1064083)
    + S8181692, CVE-2017-10356: Update storage implementations
    (bsc#1064084)
    + S8183028, CVE-2016-10165: Improve CMS header processing
    (bsc#1064069)
  * Other fixes
    + S8178714: PKIX validator nameConstraints check failing after
    change 8175940
    + S8179564: Missing @bug for tests added with JDK-8165367
    + S8181048: Refactor existing providers to refer to the same
    constants for default values for key length
    + S8181788: Unable to build JDK10 on SPARC-M8 machines
    + S8182879: Add warnings to keytool when using JKS and JCEKS
    + S8183297: Allow duplicate bugid for changeset in jdk9 update
    forest
    + S8184937: LCMS error 13: Couldn't link the profiles
* Tue Oct 24 2017 fstrba@suse.com
- Added patch:
  * load_java_atk_wrapper.patch
    + put jar that is specified in accessibility.properties file in
    assistive_technologies.classpath property on the class path
* Fri Oct 13 2017 fstrba@suse.com
  Make the conditions for aot a bit more readable
* Tue Oct 10 2017 fstrba@suse.com
- For accessibility subpackage, adapt to where the OpenJDK9 expects
  to find the *.properties files and the *.jar files.
* Mon Oct  2 2017 fstrba@suse.com
- Change the requirement of tzdata-java8 to Recommends, since it is
  not strictly needed.
* Thu Sep 28 2017 fstrba@suse.com
- Added patch:
  * alternative-tzdb_dat.patch
    + Allow specifying alternative path where to find the tzdb.dat
    file. With fallback to $JAVA_HOME/lib/tzdb.dat
- Don't symlink tzdb.dat in postinstall
* Thu Sep 21 2017 fstrba@suse.com
- OpenJDK 9 official release
  * version 9.0.0.0
- Update the provided jdbc-stdext version to 4.3
- Build jaotc on supported platform
- Package the jmod files as a separate %%{name}-jmod package
* Thu Sep 21 2017 fstrba@suse.com
- Allow bootstrapping with any of Java 8 or 9
* Mon Sep 11 2017 fstrba@suse.com
- Added patch:
  * disable-doclint-by-default.patch
  - Disable doclint by default when running javadoc. Doclint is
    too strict, breaks javadoc compilation and, in general,
    breaks the build for old code known to build with previous
    versions of OpenJDK.
* Thu Aug 31 2017 fstrba@suse.com
- Added patch:
  * zero-atomic_copy64.patch
  - Fix wrong assembly for ppc and s390
- Removed patch:
  * ppc32-atomic_copy64.patch
  - Replaced by the added patch above
* Thu Aug 31 2017 fstrba@suse.com
- Added patch:
  * ppc32-atomic_copy64.patch
  - fix in a zero assembly for PPC that prevented 32-bit ppc
    build to succeed
- Removed patch:
  * 8073754-stack-overflow-9-build.patch
  - rendered unnecessary by the above
- Minor packaging fixes for zero build architectures
* Mon Aug 28 2017 fstrba@suse.com
- Redo packaging to correspond to the upstream layout and avoid
  distributing the JRE twice
- Re-enable bootcycle build for all architectures and distributions
- Add more recent systemtap-tapset tarball
- Added patch:
  * bootcycle_jobs.patch
  - fix bootcycle build
* Thu Aug 24 2017 fstrba@suse.com
- Package the conf directories in jre and jdk. Fixes bsc#1047842.
* Wed Aug 23 2017 fstrba@suse.com
- Update to ustream tag jdk-9+181
- Added patches:
  * java-9-openjdk-linuxfilestore.patch
  - Fix bsc#1032647, bsc#1052009 with btrfs subvolumes and
    overlayfs
  * 8073754-stack-overflow-9-build.patch
  - Fix stack overflows in ppc build
* Mon Jul 24 2017 fstrba@suse.com
- Update to upstream tag jdk-9+179
* Tue Jul 18 2017 fstrba@suse.com
- Update to upstream tag jdk-9+178
* Fri Jun 30 2017 fstrba@suse.com
- Update to upstream tag jdk-9+176
* Thu Jun 22 2017 dimstar@opensuse.org
- Also require jpackage-utils instead of jpackage-utils-java9 in
  java-9-openjdk-javadoc (boo#1042550).
* Fri Jun 16 2017 dimstar@opensuse.org
- Require jpackage-utils instead of jpackage-utils-java9: that
  symbol had been dropped a while back, resulting in java 9 being
  uninstallable (boo#1042550).
* Fri Jun 16 2017 fstrba@suse.com
- Update to upstream tag jdk-9+174
- Removed patch:
  * java-9-openjdk-minmax.patch
    + fixed upstream
* Fri Jun  9 2017 fstrba@suse.com
- Update to upstream tag jdk-9+173
* Sun May 28 2017 fstrba@suse.com
- Update to upstream tag jdk-9+171
* Fri May 12 2017 fstrba@suse.com
- Update to upstream tag jdk-9+169
* Fri May  5 2017 fstrba@suse.com
- Update to upstream tag jdk-9+168
* Thu May  4 2017 fstrba@suse.com
- Update to upstream tag jdk-9+167
* Fri Apr 28 2017 fstrba@suse.com
- Change the java_ver variable from 1.9.0 to 9
* Mon Apr 24 2017 fstrba@suse.com
- Update to upstream tag jdk-9+166
* Fri Apr  7 2017 fstrba@suse.com
- Update to upstream tag jdk-9+164
- Rename package java-1_9_0-openjdk -> java-9-openjdk to account
  for changes in upstream versioning scheme
- Added patch:
  * system-pcsclite.patch
    + Allow building against system pcsc where possible
* Fri Mar 31 2017 fstrba@suse.com
- Update to upstream tag jdk-9+163
* Fri Mar 24 2017 fstrba@suse.com
- Update to upstream tag jdk-9+162
* Wed Mar 22 2017 fstrba@suse.com
- Update to upstream tag jdk-9+161
* Fri Mar 10 2017 fstrba@suse.com
- Update to upstream tag jdk-9+160
* Tue Mar  7 2017 fstrba@suse.com
- Remove jsadebugd and jsadebugd.1* slaves from alternatives, since
  the binaries are not part of openjdk any more (bsc#1020853)
* Sun Mar  5 2017 fstrba@suse.com
- Update to upstream tag jdk-9+159
* Tue Feb 21 2017 fstrba@suse.com
- Update to upstream tag jdk-9+157
* Fri Feb 10 2017 fstrba@suse.com
- Update to upstream tag jdk-9+156
* Fri Feb  3 2017 fstrba@suse.com
- Update to upstream tag jdk-9+155
- Changed patch
  * s390-java-opts.patch
  - rewrite the patch to correspond to the new boot-jdk.m4
* Wed Feb  1 2017 fstrba@suse.com
- Update to upstream tag jdk-9+154
- Use the new accelerated hotspot port for s390x, which fixes
  the build on this architecture
- Modified patches:
  * java-atk-wrapper-security.patch
  * multiple-pkcs11-library-init.patch
  - rediff to changed context
* Thu Jan 26 2017 fstrba@suse.com
- Changed patch:
  * s390-size_t.patch
  - rediff
* Mon Jan 23 2017 fstrba@suse.com
- Update to upstream tag jdk-9+153
* Fri Jan 13 2017 fstrba@suse.com
- Update to upstream tag jdk-9+152
* Tue Jan 10 2017 fstrba@suse.com
- Upgrade to upstream tag jdk-9+151
- Removed patches:
  * ppc-zero-hotspot.patch
  - Integrated upstream
  * 1015432.patch
  - Not needed any more
- Added patch:
  * sorted-diff.patch
  - Assure that diffs are sorted
- Deleted file:
  * TestCryptoLevel.java
  - Not needed since unlimited crypto is now the default
- Modified files:
  * config.guess
  * config.sub
  - Update to newest versions from config.git
* Tue Sep 27 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+137
- Changed patches:
  * java-1_9_0-openjdk-minmax.patch
  * s390-java-opts.patch
  - Sync with Fedora
- Added patch
  * ppc_stack_overflow_fix.patch
  - Fix stack overflow on ppc
* Fri Sep  9 2016 fstrba@suse.com
- Added patches:
  * jdk9-gcc6.patch
  - miscellaneous fixes from jdk bugzilla, relative to building
    problems with gcc6
  * java-1_9_0-openjdk-minmax.patch
  - Undef min and max to avoid unwanted defines in random places
- Avoid bootcycle build which is still broken
* Fri Sep  2 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+134
* Wed Jun 29 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+124
- Added patch:
  * java-1_9_0-openjdk-gcc6.patch
  - allow building with gcc6 default c++ style
- Removed patch:
  * hotspot-nowerror.patch
  - not needed anymore
* Fri Jun 17 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+123
* Fri Jun 10 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+122
* Fri Jun  3 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+121
* Fri May 13 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+118
* Fri May  6 2016 jengelh@inai.de
- Avoid bashisms in spec file (uses /bin/sh by default)
- Fix incorrect stat call: %%{s} is read as a rpm macro
* Tue May  3 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+116
- Fix cpio error during update due to change in "modules" directory
  to a "modules" file.
* Fri Apr  8 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+113
* Fri Mar 18 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+110
* Fri Mar  4 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+108
* Tue Mar  1 2016 fstrba@suse.com
- Upgrade to upsteam tag jdk-9+107
- Changed patch:
  * hotspot-nowerror.patch
    + rediff to changed context
* Mon Feb 22 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+106
- Architecture install directory for ppc64le changes
  * ppc64 -> ppc64le
* Fri Feb 12 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+105
- Removed patches:
  * zero-JavaThread-fix.patch
  * register_ppc.patch
    + integrated upstream
* Mon Feb  8 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+104
- Added patch:
  * zero-JavaThread-fix.patch
    + Fix: Interpreter functions are declared and defined in the
    wrong files
* Fri Jan 29 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+103
- Modified patches:
  * 1015432.patch
  * PStack-808293.patch
  * zero-ranges.patch
  * s390-size_t.patch
    + rediff to the changed context
- Added patch:
  * register_ppc.patch
    + if/endif mismatch in the file register_ppc.hpp
* Tue Jan 26 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+102
* Thu Jan 14 2016 fstrba@suse.com
- Added patch:
  * hotspot-nowerror.patch: disable warnings being errors in
    hostspot. It causes unnecessary build failure on some
    architectures.
* Tue Jan 12 2016 fstrba@suse.com
- Upgrade to upstream tag jdk-9+100
* Fri Nov 20 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b93
- Removed patches:
  * fix-system-jpeg-loading.patch
  - integrated upstream
- Added patch:
  * fix-zero-k_entry.patch
  - backport upstream fix
* Fri Nov 13 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b92
- Removed patches:
  * aarch64-ranges.patch
  * fix-zero-build.patch
  - integrated upstream
* Thu Nov 12 2015 fstrba@suse.com
- Modified patches:
  * s390-java-opts.patch
  * s390-size_t.patch
  - rediff to the new context
* Wed Nov 11 2015 fstrba@suse.com
- Added patch:
  * zero-ranges.patch
  - fix broken instantiation of VM on ppc32 and maybe other
    ZERO architectures
* Fri Nov  6 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b91
* Thu Nov  5 2015 fstrba@suse.com
- Added patch:
  * aarch64-ranges.patch
  - fix broken instantiation of VM on aarch64
* Tue Nov  3 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b90
* Tue Nov  3 2015 fstrba@suse.com
- Added patch:
  * fix-zero-build.patch
  - fix broken zero build after signatures of some functions
    changed
* Fri Oct 30 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b89
- Removed patch:
  * link-with-as-needed.patch
  - integrated upstream
- Modified patch:
  * memory-limits.patch
  - rediff to correspond to the new context
* Tue Oct 20 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b87
- Modified patch:
  * s390-size_t.patch
  - Adapt to changed context
* Fri Oct  9 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b85
- Adapt to changed strip options
* Tue Oct  6 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b84
- Removed patch:
  * arm-hotspot-fix.patch
  - fixed upstream
* Mon Sep 28 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b83
* Sat Sep 19 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b82
* Tue Sep 15 2015 fstrba@suse.com
- Add --with-boot-jdk-jvmargs="-XX:ThreadStackSize=2240" as
  configure option for PPC
  * Increase the stack size of the jdk8 used to bootstrap jdk9
    build
- Modified patch:
  * ppc-zero-hotspot.patch
  - increase the default stack size for jdk9 on PPC
* Mon Sep 14 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b81
- Removed patch:
  * aarch64-fix.patch
  - integrated upstream
* Mon Sep  7 2015 schwab@suse.de
- arm-hotspot-fix.patch: replace undefined ARM32 with ARM
* Fri Sep  4 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b80
- Modified patch:
  * java-atk-wrapper-security.patch
  - Rediff to the new context
* Wed Sep  2 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b79
- Update the config.guess and config.sub to newer versions
- Added patch:
  * aarch64-fix.patch
  - Fix an undefined symbol in aarch64 build
* Mon Aug 24 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b78
* Tue Aug 18 2015 fstrba@suse.com
- Add _constraints file
* Tue Aug 18 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b77
  * fix bsc#941987
- Removed patch:
  * constant_too_wide_for_long.patch
  - Fixed differently upstream
* Fri Jul 24 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b74
- Removed patch:
  * disable-doclint-by-default.patch
  - the surrounding code changed completely and it builds without
    it anyway
* Mon Jul 20 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b73
* Sat Jul 11 2015 fstrba@suse.com
- Removed patch:
  * applet-hole.patch
  - not needed with recent icedtea-web versions any more
* Thu Jul  9 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b72
- Removed patches:
  * ppc64le-emit_fd.patch
  * aarch64.patch
  - applied upstream
* Fri Jul  3 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b71
* Mon Jun 29 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b70
- Removed patches:
  * eventFilter.patch
  * giflib.patch
  * zero-dummy.patch
  - integrated upstream
* Tue Jun 23 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b69
* Thu Jun 18 2015 tchvatal@suse.com
- Use priority matching to ibm-java, always 5 bigger than it
* Mon Jun 15 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b68
- Added patches:
  * ppc64le-emit_fd.patch
  - fix build on PPC64LE
  * constant_too_wide_for_long.patch
  - fix build on 32-bit systems with older compilers
- Modified patch:
  * s390-size_t.patch
  - rediff to account for changes in directory structures
* Wed Jun 10 2015 fstrba@suse.com
- Added patch:
  * zero-dummy.patch
  - Fix crash in ZERO VM built with gcc5
* Mon Jun  8 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b67
- Added patch:
  * aarch64.patch
  - fix build on aarch64 architecture
* Tue Jun  2 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b66
* Sun May 24 2015 scalpel4k@gmail.com
- Added patch:
  * eventFilter.patch
  - fix build with gcc5 that is picky about missing brackets.
* Fri May 22 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b65
- Removed patch:
  * system-giflib5.patch
  - fixed upstream
- Added patch:
  * giflib.patch
  - Allow building with system giflib versions before 5.1
- Modified patch:
  * s390-size_t.patch
  - Rediff to a new context and code state.
- Add --disable-warnings-as-errors to the configure line
  * avoiding to fail on first little warning.
* Tue May  5 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b62
- Removed patch:
  * configure-errors.patch
  - fixed upsteam
* Wed Apr 22 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b60
- Updated patches:
  * memory-limits.patch
  * ppc-zero-hotspot.patch
  - rediff to correspond to the uintx -> size_t changes
- Added patch:
  * configure-errors.patch
  - revert hunks of upstream commit that break the build in our
    build environment
* Mon Apr 13 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b57
* Fri Apr 10 2015 fstrba@suse.com
- Build aarch64 as JIT accelerated JVM
* Mon Mar 30 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b56
- Removed integrated patch:
  * hotspot-missing-symbol.patch
* Sun Mar 29 2015 fstrba@suse.com
- Modified patch:
  * s390-size_t.patch
  - Rediff and patch some more problems
* Fri Mar 20 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b55
- Modified patch:
  * link-with-as-needed.patch
  - Rediff to account for changes in file names
* Fri Mar 13 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b54
  * Remove need of different tarball for AARCH64
  * AARCH64 changes integrated upstream in this tag
- Remove patches:
  * aarch64-hotspot.patch, aarch64-misc.patch
  - Integrated upstream
- Added patch:
  * hotspot-missing-symbol.patch
  - Upstream fix for linking problem in CPP interpreter
* Thu Mar  5 2015 fstrba@suse.com
- Updated patch:
  * s390-size_t.patch
  - patch one more occurence of uintx/size_t mismatch
* Fri Feb 20 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b51
- Updated patches:
  * link-with-as-needed.patch
  * s390-size_t.patch
  - rediff to the new context
- Added patch:
  * aarch64-hotspot.patch
  - forward-port the symbol JVM_GetNanoTimeAdjustment that is
    not part of aarch64 tarball
* Tue Feb 17 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b50
- Update the aarch64 hotspot to the current tip of aarch64-port
  stage repository
- Added patch
  * fix-system-jpeg-loading.patch
  - correct the case mismatch that prevented JPEG decoder from
    working correctly (boo#905950)
* Thu Jan 29 2015 fstrba@suse.com
- Upgrade to upstream tag jdk9-b48
- Use the aarch64-port stage repository for aarch64 hotspot
- Added patch:
  * icedtea-sound-1.0.1-runtime.patch
  - Allow building against jdk9 post b41 which does not have
    any more jar files.
* Sun Jan 25 2015 fstrba@suse.com
- Modify patch: system-giflib5.patch
  * Fix build with giflib 5.1.x
* Mon Dec  8 2014 fstrba@suse.com
- Require versions of jpackage-utils and tzdata-java compatible
  with this version of Java.
* Tue Nov 11 2014 fstrba@suse.com
- Add the jvm.cfg file for aarch64
  * hopefully fixes aarch64 build
* Mon Nov 10 2014 fstrba@suse.com
- Put manpage alternative for policy-tool to the right package
* Wed Nov  5 2014 fstrba@suse.com
- Upgrade to upstream tag jdk9-b37
- Upgrade to new tip of aarch64 hotspot including b37 changes
- Remove aarch64-b35.patch
  * changes integrated in the new aarch64 hotspot tip
* Wed Oct 29 2014 fstrba@suse.com
- Update config.sub and config.guess to the recent master of
  http://git.savannah.gnu.org/cgit/config.git
- Add aarch64 back to JIT architectures to see whether it builds
  better
- Don't apply 1015432.patch for aarch64
  * Whitespace difference causes problems for a patch that is not
    needed for aarch64
* Fri Oct 17 2014 fstrba@suse.com
- Upgrade to upstream jdk9-b35 tag
- Add patch: aarch64-b35.patch
  * bring changes from jdk9-b35 to the aarch64 hotspot tarball
    manually
* Thu Oct 16 2014 fstrba@suse.com
- Allow building for SLE11
  * Conditionalize BuildRequires
  * Conditionalize cxxflags not understood by gcc 4.3
  * Conditionalize javadoc noarch build for distributions that
    understand the per-package BuildArch
- Try to make the jre-32 and jre-64 provides more automatic
- Disable brp-check-bytecode-version during install
  * java9 will have bytecode version 9 in its jars
* Thu Oct  2 2014 fstrba@suse.com
- Initial java-1_9_0-openjdk package based on jdk9-b32
